# mlkatas

Utility functions for Machine Learning.

Mostly compiled from the article series [Applied Deep Learning](https://towardsdatascience.com/applied-deep-learning-part-1-artificial-neural-networks-d7834f67a4f6) and examples from the book [Deep Learning with Python](https://github.com/fchollet/deep-learning-with-python-notebooks).
